cgexplore.terms.TargetMartiniBond
=================================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetMartiniBond
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetMartiniBond.human_readable
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetMartiniBond.type1
      ~TargetMartiniBond.type2
      ~TargetMartiniBond.element1
      ~TargetMartiniBond.element2
      ~TargetMartiniBond.funct
      ~TargetMartiniBond.bond_r
      ~TargetMartiniBond.bond_k
   
   